@@ -6,6 +6,7 @@ in the source distribution for its full text.
 */
 
 #include "AffinityPanel.h"
+#include "CRT.h"
 
 #include "CheckItem.h"
 
@@ -23,6 +24,7 @@ static HandlerResult AffinityPanel_eventHandler(Panel* this, int ch) {
    CheckItem* selected = (CheckItem*) Panel_getSelected(this);
    switch(ch) {
    case KEY_MOUSE:
+   case KEY_RECLICK:
    case ' ':
       CheckItem_set(selected, ! (CheckItem_get(selected)) );
       return HANDLED;
@@ -43,14 +45,14 @@ PanelClass AffinityPanel_class = {
 };
 
 Panel* AffinityPanel_new(ProcessList* pl, Affinity* affinity) {
-   Panel* this = Panel_new(1, 1, 1, 1, true, Class(CheckItem));
+   Panel* this = Panel_new(1, 1, 1, 1, true, Class(CheckItem), FunctionBar_newEnterEsc("Set    ", "Cancel "));
    Object_setClass(this, Class(AffinityPanel));
 
    Panel_setHeader(this, "Use CPUs:");
    int curCpu = 0;
    for (int i = 0; i < pl->cpuCount; i++) {
       char number[10];
-      snprintf(number, 9, "%d", ProcessList_cpuId(pl, i));
+      xSnprintf(number, 9, "%d", Settings_cpuId(pl->settings, i));
       bool mode;
       if (curCpu < affinity->used && affinity->cpus[curCpu] == i) {
          mode = true;
@@ -58,13 +60,13 @@ Panel* AffinityPanel_new(ProcessList* pl, Affinity* affinity) {
       } else {
          mode = false;
       }
-      Panel_add(this, (Object*) CheckItem_new(strdup(number), NULL, mode));
+      Panel_add(this, (Object*) CheckItem_newByVal(xStrdup(number), mode));
    }
    return this;
 }
 
-Affinity* AffinityPanel_getAffinity(Panel* this) {
-   Affinity* affinity = Affinity_new();
+Affinity* AffinityPanel_getAffinity(Panel* this, ProcessList* pl) {
+   Affinity* affinity = Affinity_new(pl);
    int size = Panel_size(this);
    for (int i = 0; i < size; i++) {
       if (CheckItem_get((CheckItem*)Panel_get(this, i)))
