@@ -20,35 +20,35 @@ int LoadAverageMeter_attributes[] = {
 
 int LoadMeter_attributes[] = { LOAD };
 
-static void LoadAverageMeter_setValues(Meter* this, char* buffer, int size) {
+static void LoadAverageMeter_updateValues(Meter* this, char* buffer, int size) {
    Platform_getLoadAverage(&this->values[0], &this->values[1], &this->values[2]);
-   snprintf(buffer, size, "%.2f/%.2f/%.2f", this->values[0], this->values[1], this->values[2]);
+   xSnprintf(buffer, size, "%.2f/%.2f/%.2f", this->values[0], this->values[1], this->values[2]);
 }
 
 static void LoadAverageMeter_display(Object* cast, RichString* out) {
    Meter* this = (Meter*)cast;
    char buffer[20];
-   sprintf(buffer, "%.2f ", this->values[0]);
+   xSnprintf(buffer, sizeof(buffer), "%.2f ", this->values[0]);
    RichString_write(out, CRT_colors[LOAD_AVERAGE_ONE], buffer);
-   sprintf(buffer, "%.2f ", this->values[1]);
+   xSnprintf(buffer, sizeof(buffer), "%.2f ", this->values[1]);
    RichString_append(out, CRT_colors[LOAD_AVERAGE_FIVE], buffer);
-   sprintf(buffer, "%.2f ", this->values[2]);
+   xSnprintf(buffer, sizeof(buffer), "%.2f ", this->values[2]);
    RichString_append(out, CRT_colors[LOAD_AVERAGE_FIFTEEN], buffer);
 }
 
-static void LoadMeter_setValues(Meter* this, char* buffer, int size) {
+static void LoadMeter_updateValues(Meter* this, char* buffer, int size) {
    double five, fifteen;
    Platform_getLoadAverage(&this->values[0], &five, &fifteen);
    if (this->values[0] > this->total) {
       this->total = this->values[0];
    }
-   snprintf(buffer, size, "%.2f", this->values[0]);
+   xSnprintf(buffer, size, "%.2f", this->values[0]);
 }
 
 static void LoadMeter_display(Object* cast, RichString* out) {
    Meter* this = (Meter*)cast;
    char buffer[20];
-   sprintf(buffer, "%.2f ", ((Meter*)this)->values[0]);
+   xSnprintf(buffer, sizeof(buffer), "%.2f ", ((Meter*)this)->values[0]);
    RichString_write(out, CRT_colors[LOAD], buffer);
 }
 
@@ -58,7 +58,7 @@ MeterClass LoadAverageMeter_class = {
       .delete = Meter_delete,
       .display = LoadAverageMeter_display,
    },
-   .setValues = LoadAverageMeter_setValues, 
+   .updateValues = LoadAverageMeter_updateValues,
    .defaultMode = TEXT_METERMODE,
    .maxItems = 3,
    .total = 100.0,
@@ -75,8 +75,9 @@ MeterClass LoadMeter_class = {
       .delete = Meter_delete,
       .display = LoadMeter_display,
    },
-   .setValues = LoadMeter_setValues, 
+   .updateValues = LoadMeter_updateValues,
    .defaultMode = TEXT_METERMODE,
+   .maxItems = 1,
    .total = 100.0,
    .attributes = LoadMeter_attributes,
    .name = "Load",
