@@ -1,23 +1,26 @@
 /*
 htop - UsersTable.c
-(C) 2004-2010 Hisham H. Muhammad
+(C) 2004-2011 Hisham H. Muhammad
 Released under the GNU GPL, see the COPYING file
 in the source distribution for its full text.
 */
 
 #include "UsersTable.h"
-#include "Hashtable.h"
-#include "String.h"
+#include "XAlloc.h"
+
+#include "config.h"
 
 #include <stdio.h>
+#include <string.h>
 #include <strings.h>
 #include <pwd.h>
 #include <sys/types.h>
-
-#include "debug.h"
+#include <stdlib.h>
 #include <assert.h>
 
 /*{
+#include "Hashtable.h"
+
 typedef struct UsersTable_ {
    Hashtable* users;
 } UsersTable;
@@ -25,7 +28,7 @@ typedef struct UsersTable_ {
 
 UsersTable* UsersTable_new() {
    UsersTable* this;
-   this = malloc(sizeof(UsersTable));
+   this = xMalloc(sizeof(UsersTable));
    this->users = Hashtable_new(20, true);
    return this;
 }
@@ -40,7 +43,7 @@ char* UsersTable_getRef(UsersTable* this, unsigned int uid) {
    if (name == NULL) {
       struct passwd* userData = getpwuid(uid);
       if (userData != NULL) {
-         name = String_copy(userData->pw_name);
+         name = xStrdup(userData->pw_name);
          Hashtable_put(this->users, uid, name);
       }
    }
