@@ -61,8 +61,8 @@ ProcessFieldData Process_fields[] = {
    [STATE] = { .name = "STATE", .title = "S ", .description = "Process state (S sleeping, R running, D disk, Z zombie, T traced, W paging)", .flags = 0, },
    [PPID] = { .name = "PPID", .title = "   PPID ", .description = "Parent process ID", .flags = 0, },
    [PGRP] = { .name = "PGRP", .title = "   PGRP ", .description = "Process group ID", .flags = 0, },
-   [SESSION] = { .name = "SESSION", .title = "   SESN ", .description = "Process's session ID", .flags = 0, },
-   [TTY_NR] = { .name = "TTY_NR", .title = "  TTY ", .description = "Controlling terminal", .flags = 0, },
+   [SESSION] = { .name = "SESSION", .title = "    SID ", .description = "Process's session ID", .flags = 0, },
+   [TTY_NR] = { .name = "TTY_NR", .title = "    TTY ", .description = "Controlling terminal", .flags = 0, },
    [TPGID] = { .name = "TPGID", .title = "  TPGID ", .description = "Process ID of the fg process group of the controlling terminal", .flags = 0, },
    [MINFLT] = { .name = "MINFLT", .title = "     MINFLT ", .description = "Number of minor faults which have not required loading a memory page from disk", .flags = 0, },
    [MAJFLT] = { .name = "MAJFLT", .title = "     MAJFLT ", .description = "Number of major faults which have required loading a memory page from disk", .flags = 0, },
@@ -92,7 +92,7 @@ ProcessPidColumn Process_pidColumns[] = {
    { .id = TPGID, .label = "TPGID" },
    { .id = TGID, .label = "TGID" },
    { .id = PGRP, .label = "PGRP" },
-   { .id = SESSION, .label = "SESN" },
+   { .id = SESSION, .label = "SID" },
    { .id = 0, .label = NULL },
 };
 
@@ -117,9 +117,9 @@ void FreeBSDProcess_writeField(Process* this, RichString* str, ProcessField fiel
    int n = sizeof(buffer) - 1;
    switch ((int) field) {
    // add FreeBSD-specific fields here
-   case JID: snprintf(buffer, n, Process_pidFormat, fp->jid); break;
+   case JID: xSnprintf(buffer, n, Process_pidFormat, fp->jid); break;
    case JAIL:{
-      snprintf(buffer, n, "%-11s ", fp->jname); break;
+      xSnprintf(buffer, n, "%-11s ", fp->jname); break;
       if (buffer[11] != '\0') {
          buffer[11] = ' ';
          buffer[12] = '\0';
